@@ -8,7 +8,7 @@ from .utils import Utils
 from django.conf import settings
 from log_labeler import local, LOG_LABEL_REQUEST_SETTING, DEFAULT_HEADER_VALUE, \
         MAX_REQUEST_RESPONSE_SIZE, DEFAULT_LOG_LEVEL, \
-        NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, LOGGING, LOG_LABEL_OBFUSCATE
+        NIM_DJANGO_REQUEST_LOG_LEVEL_NAME, LOGGING
 
 logger = logging.getLogger(__name__)
 
@@ -43,47 +43,12 @@ class HeaderToLabelMiddleware(object):
 
         self.get_response = get_response
 
-
-    def __get_time_in_milliseconds(self):
-        return int(round(time.time() * 1000))
-
-    def __is_debug(self):
-        return logger.level != logging.INFO
-
-    def __obfuscate_headers(self, headers):
-        _headers = headers.copy()
-        log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
-        if "headers" in log_label_obfuscate:
-            for header_name in log_label_obfuscate["headers"]:
-                if header_name in _headers:
-                    _headers[header_name] = self._OBFUSCATE_INDICATOR
-
-        return _headers
-
-    def __obfuscate_body(self, body):
-        log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
-        if "body" in log_label_obfuscate:
-            for pattern, replacement in log_label_obfuscate["body"].items():
-                if re.search(pattern, body):
-                    body = re.sub(pattern, replacement, body)
-
-        return body
-
-    def __obfuscate_response(self, response):
-        log_label_obfuscate = getattr(settings, LOG_LABEL_OBFUSCATE, dict())
-        if "response" in log_label_obfuscate:
-            for pattern, replacement in log_label_obfuscate["response"].items():
-                if re.search(pattern, response):
-                    response = re.sub(pattern, replacement, response)
-
-        return response
-
     def process_request(self, request):
         self._initial_http_body = request.body
-        self._request_start_time = self.__get_time_in_milliseconds()
+        self._request_start_time = Utils.get_time_in_milliseconds()
         log_label_request_settings = getattr(settings, LOG_LABEL_REQUEST_SETTING, dict())
 
-        headers = self.__obfuscate_headers(Utils.get_all_headers(request))
+        headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
 
         log_entry_info = dict(
             type=self._REQUEST,
@@ -96,9 +61,9 @@ class HeaderToLabelMiddleware(object):
         log_entry_debug = dict(
             type=self._REQUEST,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=self.__obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
+            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
             url=request.build_absolute_uri()
         )
         log_entry_debug.update(headers)
@@ -114,16 +79,16 @@ class HeaderToLabelMiddleware(object):
         logger.info('', extra=log_entry_info)
 
     def process_response(self, request, response):
-        headers = self.__obfuscate_headers(Utils.get_all_headers(request))
+        headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
         log_entry = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=self.__obfuscate_body(Utils.adjust_string_length(self._initial_http_body,
+            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body,
                                             getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if response.status_code < 400 else self._initial_http_body),
             status_code=response.status_code,
-            response=self.__obfuscate_response(Utils.adjust_string_length(response.content,
+            response=Utils.obfuscate_response(Utils.adjust_string_length(response.content,
                                                 settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else response.content),
             url=request.build_absolute_uri()
         )
@@ -132,7 +97,7 @@ class HeaderToLabelMiddleware(object):
         log_entry_info = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=Utils.get_time_in_milliseconds(),
             status_code=response.status_code,
             method=request.method,
             url=request.build_absolute_uri()
@@ -159,13 +124,13 @@ class HeaderToLabelMiddleware(object):
         return response
 
     def process_exception(self, request, exception):
-        headers = self.__obfuscate_headers(Utils.get_all_headers(request))
+        headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
         log_entry = dict(
             type=self._ERROR,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
-            body=self.__obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
+            body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body, getattr(settings, MAX_REQUEST_RESPONSE_SIZE))),
             status_code="500",
             exception=str(exception),
             url=request.build_absolute_uri(),
@@ -176,7 +141,7 @@ class HeaderToLabelMiddleware(object):
         log_entry_info = dict(
             type=self._ERROR,
             request_start_time_ms=self._request_start_time,
-            request_end_time_ms=self.__get_time_in_milliseconds(),
+            request_end_time_ms=Utils.get_time_in_milliseconds(),
             status_code="500",
             method=request.method,
             url=request.build_absolute_uri()
